﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace LumiFix
{
    public partial class Form1 : Form
    {

        private bool protectOn = false;
        private List<Layer> layers = new List<Layer>();
        
        public Form1()
        {
            this.SizeChanged += new System.EventHandler(this.MainFormSizeChanged);

            InitializeComponent();

            notifyIcon.MouseClick += new System.Windows.Forms.MouseEventHandler(this.notifyIcon_MouseClick);

            foreach (Screen s in Screen.AllScreens)
            {
                screensCheckboxs.Items.Add(ImproveScreenName(s), true);
            }
        }

        private string ImproveScreenName(Screen s)
        {
            string name = s.DeviceName;
            if (s.Primary)
            {
                name += " (écran principal)";
            }
            return name.Replace(".", "").Replace("\\", "");
        }


        private void applyOptions_Click(object sender, EventArgs e)
        {
            int opacity = trackBar1.Maximum - trackBar1.Value;

            foreach (Layer layer in layers)
            {
                layer.UpdateOpacity(opacity);

                if (screensCheckboxs.CheckedItems.Contains(layer.ScreenName))
                {
                    layer.Show();
                }
                else
                {
                    layer.Hide();
                }
            }
        }

        private void protectButtonClick(object sender, EventArgs e)
        {
            toggleProtect();
        }

        private void toggleProtect()
        {
            if (protectOn)
            {
                disableProtect();
            }
            else
            {
                enableProtect();
            }
        }

        private void disableProtect()
        {
            foreach (Layer l in layers)
            {
                l.Close();
                l.Dispose();
            }
            layers.Clear();

            protectOn = false;
            protectButton.Text = "Protéger mes petits yeux !";
            notifyIcon.Text = "LumiFix (désactivé)";
        }

        private void enableProtect()
        {
            int opacity = trackBar1.Maximum - trackBar1.Value;
            layers.Clear();

            foreach (Screen s in Screen.AllScreens)
            {
                Layer layer = new Layer();
                layer.InitLayer(s, ImproveScreenName(s), opacity);

                if (screensCheckboxs.CheckedItems.Contains(layer.ScreenName))
                {
                    layer.Show();
                }

                layers.Add(layer);
            }

            protectOn = true;
            protectButton.Text = "Enlever la protection, même pas peur !";
            notifyIcon.Text = "LumiFix (activé)";
        }

        private void MainFormSizeChanged(object sender, System.EventArgs e)
        {
            if (WindowState == FormWindowState.Minimized)
            {
                this.Hide();
                notifyIcon.Visible = true;
            }
        }

        private void notifyIcon_MouseClick(object sender, MouseEventArgs e)
        {
            if (e.Button == MouseButtons.Left)
            {
                toggleProtect();
            }
            else if (e.Button == MouseButtons.Right)
            {
                this.Show();
                WindowState = FormWindowState.Normal;
            }
        }
    }
}
