﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace LumiFix
{
    public partial class Layer : Form
    {

        [DllImport("user32.dll", SetLastError = true)]
        static extern int GetWindowLong(IntPtr hWnd, int nIndex);

        [DllImport("user32.dll", SetLastError = true)]
        static extern int SetWindowLong(IntPtr hWnd, int nIndex, IntPtr dwNewLong);

        [DllImport("user32.dll", SetLastError = true)]
        static extern bool GetLayeredWindowAttributes(IntPtr hWnd, out uint crKey, out byte bAlpha, out uint dwFlags);

        [DllImport("user32.dll", SetLastError = true)]
        static extern bool SetLayeredWindowAttributes(IntPtr hWnd, uint crKey, byte bAlpha, uint dwFlags);


        public const int GWL_EXSTYLE = -20;
        public const int WS_EX_LAYERED = 0x80000;
        public const int WS_EX_TRANSPARENT = 0x20;
        public const int LWA_ALPHA = 0x2;

        private int InitialStyle;
        public string ScreenName = "";


        public Layer()
        {
            InitializeComponent();
        }

        public void InitLayer(Screen s, string name, int opacity)
        {
            SetBounds(s.Bounds.X, s.Bounds.Y, s.Bounds.Width, s.Bounds.Height);
            Name = "LumiFix : " + ScreenName;
            ScreenName = name;
            ClickThrough = true;
            LayerOpacity = _o2b(opacity);
        }


        /**
         * http://www.vbfrance.com/codes/DOC-SUR-API-SETWINDOWLONG_6137.aspx
         * http://msdn.microsoft.com/fr-fr/library/61fe4bte(v=vs.90)
         */
        public bool ClickThrough
        {
            set
            {
                InitialStyle = GetWindowLong(Handle, GWL_EXSTYLE);

                if (value)
                {
                    SetWindowLong(Handle, GWL_EXSTYLE, (IntPtr)(InitialStyle | WS_EX_LAYERED | WS_EX_TRANSPARENT));
                }
                else
                {
                    SetWindowLong(Handle, GWL_EXSTYLE, (IntPtr)(InitialStyle | WS_EX_LAYERED));
                }
            }
        }

        public byte LayerOpacity
        {
            get
            {
                uint c_crKey;
                byte c_bAlpha;
                uint c_dwFlags;

                GetLayeredWindowAttributes(Handle, out c_crKey, out c_bAlpha, out c_dwFlags);

                return c_bAlpha;
            }

            set
            {
                SetLayeredWindowAttributes(Handle, 0, value, LWA_ALPHA);
            }
        }

        public void UpdateOpacity(int opacity)
        {
            LayerOpacity = _o2b(opacity);
            this.Refresh();
        }

        /// <summary>
        /// Opacity (int) to byte
        /// </summary>
        /// <param name="p_o">Opacity value 0-100</param>
        /// <returns>Byte value between 0-255</returns>
        private byte _o2b(int p_o)
        {

            if (p_o < 0)
                p_o = 0;

            if (p_o > 100)
                p_o = 100;

            byte c_B = (byte.Parse(Math.Ceiling((255D * p_o) / 100D).ToString()));

            return c_B;
        }

    }
}
